svn commit: r1675168 - /openoffice/trunk/main/sc/source/core/tool/interpr1.cxx

2015-04-21 Thread pfg
Author: pfg
Date: Tue Apr 21 17:41:29 2015
New Revision: 1675168

URL: http://svn.apache.org/r1675168
Log:
Minor cleanups in the random generator code.

Drop unused variables.
Enhance slightly the naming of static variables.

Modified:
openoffice/trunk/main/sc/source/core/tool/interpr1.cxx

Modified: openoffice/trunk/main/sc/source/core/tool/interpr1.cxx
URL: 
http://svn.apache.org/viewvc/openoffice/trunk/main/sc/source/core/tool/interpr1.cxx?rev=1675168r1=1675167r2=1675168view=diff
==
--- openoffice/trunk/main/sc/source/core/tool/interpr1.cxx (original)
+++ openoffice/trunk/main/sc/source/core/tool/interpr1.cxx Tue Apr 21 17:41:29 
2015
@@ -1561,9 +1561,9 @@ b32MWC(void)
 }
 
 // Congruential
 #defineCNG ( cng = 69069 * cng + 13579 )
 // Xorshift
 #defineXS ( xs ^= (xs  13), xs ^= (xs  17), xs ^= (xs  5) )
 5) )
 
 #defineKISS (b32MWC() + CNG + XS)
 
@@ -1573,11 +1573,11 @@ void ScInterpreter::ScRandom()
 
 static rtlRandomPool aPool = rtl_random_createPool();
 static sal_Bool SqSeeded = sal_False;
-static sal_uInt32 i, x, cng, xs = 362436069;
+static sal_uInt32 ScCNG, ScXS = 362436069;
 
 // Seeding for the PRNG
 if (SqSeeded == sal_False) {
-rtl_random_getBytes(aPool, cng, sizeof(cng));
+rtl_random_getBytes(aPool, ScCNG, sizeof(ScCNG));
 rtl_random_getBytes(aPool, nScRandomQ,
 sizeof(nScRandomQ[0]) * SCRANDOMQ_SIZE);
 SqSeeded = sal_True;
@@ -1561,9 +1561,9 @@ b32MWC(void)
 
 // Congruential
-#defineCNG ( cng = 69069 * cng + 13579 )
+#defineCNG ( ScCNG = 69069 * ScCNG + 13579 )
 // Xorshift
@@ -1561,9 +1561,9 @@ b32MWC(void)
 // Xorshift
-#defineXS ( xs ^= (xs  13), xs ^= (xs  17), xs ^= (xs  5) )
+#defineXS ( ScXS ^= (ScXS  13), ScXS ^= (ScXS  17), ScXS ^= (ScXS 
 5) )
 




buildbot success in ASF Buildbot on openoffice-linux64-nightly

2015-04-21 Thread buildbot
The Buildbot has detected a passing build on builder openoffice-linux64-nightly 
while building ASF Buildbot. Full details are available at:
http://ci.apache.org/builders/openoffice-linux64-nightly/builds/347

Buildbot URL: http://ci.apache.org/

Buildslave for this Build: tethys_ubuntu

Build Reason: The Nightly scheduler named 'openoffice-linux64-nightly' 
triggered this build
Build Source Stamp: [branch openoffice/trunk] HEAD
Blamelist: 

Build succeeded!

Sincerely,
 -The Buildbot





buildbot failure in ASF Buildbot on openoffice-linux32-nightly

2015-04-21 Thread buildbot
The Buildbot has detected a failed build on builder openoffice-linux32-nightly 
while building ASF Buildbot. Full details are available at:
http://ci.apache.org/builders/openoffice-linux32-nightly/builds/367

Buildbot URL: http://ci.apache.org/

Buildslave for this Build: bb-vm2_ubuntu_32bit

Build Reason: The Nightly scheduler named 'openoffice-linux32-nightly' 
triggered this build
Build Source Stamp: [branch openoffice/trunk] HEAD
Blamelist: 

BUILD FAILED: failed

Sincerely,
 -The Buildbot